#
# spec file for package python-Faker
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
%define oldpython python
Name:           python-Faker
Version:        1.0.2
Release:        2.1
Summary:        Faker is a Python package that generates fake data
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/joke2k/faker
Source:         https://files.pythonhosted.org/packages/source/F/Faker/Faker-%{version}.tar.gz
BuildRequires:  %{python_module UkPostcodeParser >= 1.1.1}
BuildRequires:  %{python_module email_validator >= 1.0.2}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module more-itertools}
BuildRequires:  %{python_module pytest >= 3.8.0}
BuildRequires:  %{python_module python-dateutil >= 2.4}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six >= 1.10}
BuildRequires:  %{python_module text-unidecode >= 1.2}
BuildRequires:  fdupes
BuildRequires:  python-ipaddress
BuildRequires:  python-rpm-macros
Requires:       python-python-dateutil >= 2.4
Requires:       python-six >= 1.10
Requires:       python-text-unidecode >= 1.2
Requires(post): update-alternatives
Requires(postun): update-alternatives
BuildArch:      noarch
BuildRequires:  %{python_module pytest-runner}
%ifpython2
Requires:       python-ipaddress
Obsoletes:      %{oldpython}-fake-factory < %{version}
Provides:       %{oldpython}-fake-factory = %{version}
%endif
%ifpython3
Obsoletes:      python3-fake-factory < %{version}
Provides:       python3-fake-factory = %{version}
%endif
%python_subpackages

%description
Faker is a Python package that generates fake data. It helps with
database bootstrapping, creating XML documents, persistence stress
testing, and data anonymization from production services.

%prep
%setup -q -n Faker-%{version}
# do not hardcode pytest version
sed -i -e 's:"pytest>=3.8.0,<3.9":"pytest>=3.8.0":g' setup.py

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/faker
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%post
%python_install_alternative faker

%postun
%python_uninstall_alternative faker

%check
%python_exec setup.py test

%files %{python_files}
%license LICENSE.txt
%doc CHANGELOG.rst README.rst
%python_alternative %{_bindir}/faker
%{python_sitelib}/*

%changelog
* Thu Feb 14 2019 tchvatal@suse.com
- Update to 1.0.10:
  * Many changes to list see CHANGELOG.rst
- Run tests
* Tue Dec  4 2018 mcepl@suse.com
- Remove superfluous devel dependency for noarch package
* Wed Jan 17 2018 arun@gmx.de
- specfile:
  * update copyright year
- update to version 0.8.10:
  * Pass python_requires argument to setuptools. Thanks @jdufresne.
  * Remove some words from en_US lorem ipsum provider. Thanks @Pomax.
- changes from version 0.8.9:
  * Remove support for Python 3.3. Thanks @jdufresne.
  * Allow past dates within a second. Thanks @DanEEstar.
  * Added phone number formatting to en_GB localisation to ensure no
    genuine phone numbers are generated. Thanks @TheSapper.
  * Added en_GB localisation for SSN (UK National Insurance
    Number). Thanks @TheSapper.
  * Added ro_RO person Provider. Thanks @vasilesmartup.
  * Added domain argument to email provider. Thanks @lcd1232.
* Thu Dec 21 2017 arun@gmx.de
- update to version 0.8.8:
  * made seed_instance return self for chainability.
  * Add en_US locale for lorem. Thanks @shacker.
  * fi_FI gender specific data added. Thanks @mikkhola.
  * fi_FI address and job lists updated. Thanks @mikkhola.
  * Add iban provider. Thanks @cdaller.
* Wed Nov 15 2017 arun@gmx.de
- update to version 0.8.7:
  * Corrected some issues with the Hungarian (hu_HU) providers, such
    as incorrectly capitalized company suffixes, street/road type
    names and place names. Thanks @chrisvoncsefalvay.
  * The Hungarian locale's providers.job.job provider now returns
    Hungarian job names, taken from the Hungarian National Statistical
    Office (KSH)'s 2008 survey nomenclature of employment (FEOR
    '08). Thanks @chrisvoncsefalvay.
  * Added he_IL locale. Thanks @bjesus.
  * Fix possible infinite loop in random_sample_unique. Thanks
    @153957.
  * Add aliases to make pt_BR address provider compatible with
    en_US. Thanks @diegoholiveira.
  * Fix ResourceWarning in setup.py. Thanks @jdufresne.
  * Update test requirements.
* Sun Oct 22 2017 arun@gmx.de
- specfile:
  * added requirement for text-unidecode
- update to version 0.8.6:
  * Replace unidecode dependency in favor of text-unidecode. Faker now
    requires text-unidecode.
- changes from version 0.8.5:
  * Add ASCII emails. Thanks @barseghyanartur.
  * Add id_ID Providers. Thanks Sidi Ahmad.
  * Fix date_time.time_series() to ensure start and end bounds are
    inclusive. Thanks @bijanvakili.
  * Create a provider to Brazilian license plates. Thanks
    @diegoholiveira.
  * Use a proper international format for Ukrainian phone
    numbers. Thanks @illia-v.
  * Faker now requires Unidecode.
- changes from version 0.8.4:
  * Move email_validator to test_requires and unpinned the version
    number.
  * Date feature parity with datetime. Thanks @noirbizarre.
  * Add MSISDN in the phone_number provider. Thanks @patrickporto.
  * Add Arabic locales. Thanks @ahmedaljazzar.
  * Fix datetime issue on Windows. Thanks @kungfu71186.
* Mon Sep 11 2017 jengelh@inai.de
- Rewrite description to focus on the package.
* Wed Sep  6 2017 toddrme2178@gmail.com
- Initial version
